Learn R Programming

BioTIMEr (version 0.3.1)

scale_color_biotime: Scale construction for ggplot use

Description

Scale construction for ggplot use

Scale construction for filling in ggplot

Usage

scale_color_biotime(palette = "realms", discrete = TRUE, reverse = FALSE, ...)

scale_colour_biotime(palette = "realms", discrete = TRUE, reverse = FALSE, ...)

scale_fill_biotime(palette = "realms", discrete = TRUE, reverse = FALSE, ...)

Value

If discrete is TRUE, the function returns a colour palette produced by discrete_scale and if

discrete is FALSE, the function returns a colour palette produced by scale_color_gradient.

If discrete is TRUE, the function returns a colour palette produced by discrete_scale and if

discrete is FALSE, the function returns a colour palette produced by scale_color_gradient.

Arguments

palette

One of: `realms`, `gradient`, `cool`, `warm`, default to `realms`.

discrete

See Details. default to `FALSE`

reverse

Default to `FALSE`

...

Passed to discrete_scale or scale_color_gradient

Author

Cher F. Y. Chow

Details

USAGE NOTE: Remember to change these arguments when plotting colours continuously.